# Ideas:
#     * find out why marginal plots don't work
#     * put more information in marginals, e.g., quantiles or box plots
#     * marginal plots in different color
#     * figure out how to eliminate grid lines on the y-axis more effectively
#     * plot runtime ratios relative to lua-2.5 float or double
#     * get shorter, nicer names for the interpreters
#     * put style details in my own theme

library (ggplot2)

results <- read.csv ('benchmarks.dat.results.csv', na.strings = '')
results_sans_lua <- subset (results, binary != 'lua-2.5')
results_sans_lua <- within (results_sans_lua, {
    binary       <- factor (binary)
    interpreter  <- reorder (factor (interpreter), real)
    ast_name     <- factor (ast_name)
    string_value <- factor (string_value)
    atom_type    <- factor (atom_type)
    global_key   <- factor (global_key)
    hash         <- factor (hash)
    benchmark    <- reorder (factor (benchmark), real)
})
summary (results_sans_lua)

trellis <-
    ggplot (results_sans_lua, aes (x = real, y = benchmark)) +
    geom_jitter (alpha = I(3/4), aes (color = hash, shape = atom_type)) +
    scale_x_log10 () +
    facet_grid (ast_name + string_value + global_key ~ interpreter) +
    opts (title = 'Wall clock times for all interpreters on each benchmark') +
    xlab ('Time in seconds') +
    ylab ('Benchmark')

trellis <-
    trellis +
    opts ( panel.background = theme_rect (fill = 'grey95', colour = NA)
         , panel.grid.major = theme_line (colour = 'white', size = 0.75)
         , panel.grid.minor = theme_blank ()
         , strip.background = theme_rect (fill = 'grey87', colour = NA)
         , axis.ticks = theme_segment (colour = 'grey80')
         )

# summary (trellis)
# print (trellis)

print ("writing plot to to 'trellis.pdf'")
ggsave (plot = trellis, file = 'trellis.pdf', height = 18, width = 32)
